# TauREx3

[![PyPI](https://img.shields.io/pypi/v/taurex.svg)][pypi_]
[![Status](https://img.shields.io/pypi/status/taurex.svg)][status]
[![Python Version](https://img.shields.io/pypi/pyversions/taurex)][python version]
[![License](https://img.shields.io/pypi/l/taurex)][license]

[![Read the documentation at https://taurex3.readthedocs.io/](https://img.shields.io/readthedocs/taurex3/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/ahmed-f-alrefaie/taurex3/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/ahmed-f-alrefaie/taurex3/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi_]: https://pypi.org/project/taurex/
[status]: https://pypi.org/project/taurex/
[python version]: https://pypi.org/project/taurex
[read the docs]: https://taurex3.readthedocs.io/
[tests]: https://github.com/ucl-exoplanets/taurex3/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/ucl-exoplanets/taurex3
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black


## Installation

You can install _TauREx3_ via [pip] from [PyPI]:

```console
$ pip install taurex3
```

## Usage

Please see the [Documentation] for details.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [BSD license][license],
_TauREx3_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

<!-- github-only -->

[license]: https://github.com/ucl-exoplanets/taurex3/blob/main/LICENSE
[contributor guide]: https://github.com/ucl-exoplanets/taurex3/blob/main/CONTRIBUTING.md
[documentation]: https://taurex3.readthedocs.io/en/latest/
